@@ -20,7 +20,8 @@
 function(r,nfactors=1,n.obs = NA,n.iter=1,rotate="oblimin",scores="regression", residuals=FALSE,SMC=TRUE,covar=FALSE,missing=FALSE,impute="median", min.err = .001,max.iter=50,symmetric=TRUE,warnings=TRUE,fm="minres",alpha=.1, p =.05,oblique.scores=FALSE,np.obs=NULL,use="pairwise",cor="cor",correct=.5,weight=NULL,...) {
  cl <- match.call()
   if(isCorrelation(r)) {if(is.na(n.obs) && (n.iter >1)) stop("You must specify the number of subjects if giving a correlation matrix and doing confidence intervals")
-                               #  if(!require(MASS)) stop("You must have MASS installed to simulate data from a correlation matrix")
+                        if(length(class(r)) > 1)  { if( inherits(r,"partial.r")) class(r) <- c("matrix","array") }
+                        #in case we are using partial.r of class psych and partial.r   added 4/10/21  
                                  }
   
  f <- fac(r=r,nfactors=nfactors,n.obs=n.obs,rotate=rotate,scores=scores,residuals=residuals,SMC = SMC,covar=covar,missing=missing,impute=impute,min.err=min.err,max.iter=max.iter,symmetric=symmetric,warnings=warnings,fm=fm,alpha=alpha,oblique.scores=oblique.scores,np.obs=np.obs,use=use,cor=cor, correct=correct,weight=weight,...=...) #call fa with the appropriate parameters
@@ -401,11 +402,13 @@ FA.OLS <- function(Psi,S,nf) {
        cov = {r <- cov(r,use=use) 
               covar <- TRUE},
        wtd = { r <- cor.wt(r,w=weight)$r},
+       spearman = {r <- cor(r,use=use,method="spearman")},
+       kendall = {r <- cor(r,use=use,method="kendall")},
        tet = {r <- tetrachoric(r,correct=correct,weight=weight)$rho},
        poly = {r <- polychoric(r,correct=correct,weight=weight)$rho},
        tetrachoric = {r <- tetrachoric(r,correct=correct,weight=weight)$rho},
        polychoric = {r <- polychoric(r,correct=correct,weight=weight)$rho},
-       mixed = {r <- mixed.cor(r,use=use,correct=correct)$rho},
+       mixed = {r <- mixedCor(r,use=use,correct=correct)$rho},
        Yuleb = {r <- YuleCor(r,,bonett=TRUE)$rho},
        YuleQ = {r <- YuleCor(r,1)$rho},
        YuleY = {r <- YuleCor(r,.5)$rho } 
@@ -775,4 +778,5 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
    #modified February 11, 2013 to correctly treat SMC=FALSE as 1s instead of 0s.
    #modified spring, 2015 to use switch in the rotation options
    #modified August 25, 2015 to add rot.mat as output
-   #modified February 22, 2016 to keep the diagonal of the model as it should be -- e.g., the communalities
\ No newline at end of file
+   #modified February 22, 2016 to keep the diagonal of the model as it should be -- e.g., the communalities
+   #December 23, 2019  changed the call to mixed.cor to be mixedCor.
\ No newline at end of file
